﻿using System;
using Kernel.Services;

namespace Kernel.Objects
{
    public class Department
    {
       
        public readonly Field<Guid> InternalID;
        public readonly Field<int> DepartmentID;
        public readonly Field<string> Description;
        public readonly Field<string> ReportName;
        public readonly Field<string> DisplayName;
        public readonly Field<bool> Deleted;
        public readonly Field<bool> Taxable;
        

        private const int DESCRIPTION_MIN_LENGTH = 0;
        private const int DESCRIPTION_MAX_LENGTH = 75;
        private const int REPORT_NAME_MIN_LENGTH = 3;
        private const int REPORT_NAME_MAX_LENGTH = 15;
        private const int DISPLAY_NAME_MIN_LENGTH = 3;
        private const int DISPLAY_NAME_MAX_LENGTH = 30;
        private const int DEPARTMENT_ID_MIN_VALUE = 1;
        private const int DEPARTMENT_ID_MAX_VALUE = 5000;

        public Department()
        {
            Description = new Field<string>(new LengthValidator(DESCRIPTION_MIN_LENGTH, DESCRIPTION_MAX_LENGTH));
            ReportName = new Field<string>(new LengthValidator(REPORT_NAME_MIN_LENGTH, REPORT_NAME_MAX_LENGTH));
            DisplayName = new Field<string>(new LengthValidator(DISPLAY_NAME_MIN_LENGTH, DISPLAY_NAME_MAX_LENGTH));
            DepartmentID = new Field<int>(new RangeValidator(DEPARTMENT_ID_MIN_VALUE, DEPARTMENT_ID_MAX_VALUE));
            Deleted = new Field<bool>(null);
            Taxable = new Field<bool>(null);
            InternalID = new Field<Guid>(null);
        }
    }
}
